#
# spec file for package ghc-deriving-compat
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name deriving-compat
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2
Release:        6.12
Summary:        Backports of GHC deriving extensions
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
%endif

%description
Provides Template Haskell functions that mimic deriving extensions that were
introduced or modified in recent versions of GHC. Currently, the following
extensions are covered:

* 'DeriveFoldable'

* 'DeriveFunctor'

* 'DeriveTraversable'

The following changes have been backported:

* In GHC 8.0, 'DeriveFoldable' was changed to allow folding over data types
with existential constraints.

* In GHC 8.0, 'DeriveFoldable' and 'DeriveTraversable' were changed so as not
to generate superfluous 'mempty' or 'pure' expressions in generated code.
As a result, this allows deriving 'Traversable' instances for datatypes with
unlifted argument types.

Note that some recent GHC extensions are not covered by this package:

* 'DeriveGeneric', which was introducted in GHC 7.2 for deriving 'Generic'
instances, and modified in GHC 7.6 to allow derivation of 'Generic1' instances.
Use 'Generics.Deriving.TH' from
'<http://hackage.haskell.org/package/generic-deriving generic-deriving>' to
derive 'Generic(1)' using Template Haskell.

* 'DeriveLift', which was introduced in GHC 8.0 for deriving 'Lift' instances.
Use 'Language.Haskell.TH.Lift' from
'<http://hackage.haskell.org/package/th-lift th-lift>' to derive 'Lift' using
Template Haskell.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.2 revision 0 with cabal2obs.
